package broker

import (
	"encoding/json"
	"github.com/33cn/chain33-sdk-go/client"
	"github.com/33cn/chain33-sdk-go/types"
)

func PollingEvent(prefix, url string,meta *types.Meta) (*types.InterChainEventList, error) {
	jsonClient, err := client.NewJSONClient(prefix, url)
	if err != nil {
		return nil, err
	}
	jsonraw, err := json.Marshal(&types.PollingEvent{Meta:meta})
	if err != nil {
		return nil, err
	}
	query := client.Query4Jrpc{
		Execer:   prefix + BrokerX,
		FuncName: FuncNamePollingEvent,
		Payload:  jsonraw,
	}
	var eventList types.InterChainEventList
	err = jsonClient.Call("Chain33.Query", query, &eventList)
	if err != nil {
		return nil, err
	}
	return &eventList, nil
}

func QueryInnerMeta(prefix, url string) (*types.Meta, error) {
	jsonClient, err := client.NewJSONClient(prefix, url)
	if err != nil {
		return nil, err
	}
	jsonraw, err := json.Marshal(&types.QueryInnerMeta{})
	if err != nil {
		return nil, err
	}
	query := client.Query4Jrpc{
		Execer:   prefix + BrokerX,
		FuncName: FuncNameQueryInnerMeta,
		Payload:  jsonraw,
	}
	var meta types.Meta
	err = jsonClient.Call("Chain33.Query", query, &meta)
	if err != nil {
		return nil, err
	}
	return &meta, nil
}

func QueryOutterMeta(prefix, url string) (*types.Meta, error) {
	jsonClient, err := client.NewJSONClient(prefix, url)
	if err != nil {
		return nil, err
	}
	jsonraw, err := json.Marshal(&types.QueryOutterMeta{})
	if err != nil {
		return nil, err
	}
	query := client.Query4Jrpc{
		Execer:   prefix + BrokerX,
		FuncName: FuncNameQueryInnerMeta,
		Payload:  jsonraw,
	}
	var meta types.Meta
	err = jsonClient.Call("Chain33.Query", query, &meta)
	if err != nil {
		return nil, err
	}
	return &meta, nil
}

func QueryOutMessage(prefix, url,inServicePair string,index uint64) (*types.Response, error) {
	jsonClient, err := client.NewJSONClient(prefix, url)
	if err != nil {
		return nil, err
	}
	jsonraw, err := json.Marshal(&types.QueryOutMessage{InServicePair:inServicePair,SequenceNum:index})
	if err != nil {
		return nil, err
	}
	query := client.Query4Jrpc{
		Execer:   prefix + BrokerX,
		FuncName: FuncNameQueryOutMessage,
		Payload:  jsonraw,
	}
	var resp types.Response
	err = jsonClient.Call("Chain33.Query", query, &resp)
	if err != nil {
		return nil, err
	}
	return &resp, nil
}

func QueryInMessage(prefix, url,inServicePair string,index uint64) (*types.Response, error) {
	jsonClient, err := client.NewJSONClient(prefix, url)
	if err != nil {
		return nil, err
	}
	jsonraw, err := json.Marshal(&types.QueryInMessage{InServicePair:inServicePair,SequenceNum:index})
	if err != nil {
		return nil, err
	}
	query := client.Query4Jrpc{
		Execer:   prefix + BrokerX,
		FuncName: FuncNameQueryInMessage,
		Payload:  jsonraw,
	}
	var resp types.Response
	err = jsonClient.Call("Chain33.Query", query, &resp)
	if err != nil {
		return nil, err
	}
	return &resp, nil
}